
------------------------------------------------------------------------
-- The structure of this file is:
--
-- 1. Schema definition
-- 2. Foreign key declarations
-- 3. Data insertion
--
-- Please follow it when editing this file.
------------------------------------------------------------------------

------------------------------------------------------------------------
-- SCHEMA DEFINITION ---------------------------------------------------
------------------------------------------------------------------------

DROP DATABASE IF EXISTS psa;
CREATE DATABASE psa;
USE psa;

------------------------------------------------------------------------
---- Accounts section

-- accounts table
CREATE TABLE accounts (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- ID, autogenerated
,	type					ENUM('plain','crypt') NOT NULL DEFAULT 'plain'
								-- password type
,	password				VARCHAR(255)
								-- password text
) TYPE=InnoDB;

-- password secrets
CREATE TABLE password_secrets (
	secret					VARCHAR(255) PRIMARY KEY,
								-- secret key
	type					INT UNSIGNED NOT NULL,
								-- client type (IS_CLIENT, IS_DOMAIN_OWNER, IS_MAIL_USER)
	id						INT UNSIGNED NOT NULL,
								-- client ID
	created					DATETIME NOT NULL
								-- time of creation
) TYPE=InnoDB;

------------------------------------------------------------------------
---- Clients section

-- clients table
CREATE TABLE clients (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- client ID, autogenerated
,	cr_date					DATE
								-- client creation date
,	cname					VARCHAR(255)
								-- client company name
,	pname					VARCHAR(255) NOT NULL
								-- client personal name
,	login					VARCHAR(20) NOT NULL
								-- client PLESK login
,	account_id				INT UNSIGNED NOT NULL
								-- account id
,	status									BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- client status bitmask
,	phone					VARCHAR(255)
								-- client contact phone
,	fax						VARCHAR(255)
								-- client contact fax
,	email					VARCHAR(255)
								-- client contact e-mail
,	address					VARCHAR(255)
								-- client address
,	city					VARCHAR(255)
								-- client city
,	state					VARCHAR(255)
								-- client state
,	pcode					CHAR(10)
								-- client postoffice code
,	country					CHAR(2)
								-- client country
,	locale					VARCHAR(17) NOT NULL DEFAULT 'en-US'
								-- client locale
,	limits_id				INT UNSIGNED
								-- Limits object ID
,	params_id				INT UNSIGNED
								-- Parameters object ID
,	perm_id					INT UNSIGNED
								-- Permissions object ID
,	pool_id					INT UNSIGNED
								-- Repository object ID (IP Pool)
,	logo_id					INT UNSIGNED
								-- Client's logo
,	tmpl_id					INT UNSIGNED
								-- Repository object ID (Domain Templates List)
,	sapp_pool_id			INT UNSIGNED
								-- Repository object ID (IP Pool)
,							UNIQUE (pname)
								-- unique index on pname
,							UNIQUE (login)
								-- unique index on login
,							INDEX (account_id)
								-- REFERENCES accounts (id)
,							INDEX (limits_id)
								-- REFERENCES Limits (id)
,							INDEX (params_id)
								-- REFERENCES Parameters (id)
,							INDEX (perm_id)
								-- REFERENCES Permissions (id)
,							INDEX (pool_id)
								-- REFERENCES Repository (rep_id)
,							INDEX (logo_id)
								-- REFERENCES Logos (id)
,							INDEX (tmpl_id)
								-- REFERENCES Repository (rep_id)
,							INDEX (sapp_pool_id)
								-- REFERENCES Repository (rep_id)
) TYPE=InnoDB;

-- clients parameters table
CREATE TABLE cl_param (
	cl_id					INT UNSIGNED NOT NULL
								-- client id
,	param					VARCHAR(245) NOT NULL
								-- parameter name
,	val						VARCHAR(255)
								-- parameter value
,							PRIMARY KEY (cl_id, param)
) TYPE=InnoDB;

--	domain level users (dom_level_usrs) table
CREATE TABLE dom_level_usrs (
	dom_id					INT UNSIGNED PRIMARY KEY
								-- domain ID
,	account_id				INT UNSIGNED
								-- account id
,	state					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- domain user status from client
,	card_id					INT UNSIGNED
								-- DL user card identificator
,	perm_id					INT UNSIGNED
								-- Permissions object ID
,							INDEX (dom_id)
								-- REFERENCES domains (id)
,							INDEX (account_id)
								-- REFERENCES accounts (id)
,							INDEX (card_id)
								-- REFERENCES Cards (id)
,							INDEX (perm_id)
								-- REFERENCES Permissions (id)
) TYPE=InnoDB;

------------------------------------------------------------------------
---- Domains section

-- domains table
CREATE TABLE domains (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- domain ID, autogenerated
,	cr_date					DATE
								-- domain cretion date
,	name					VARCHAR(255) NOT NULL
								-- domain name in ASCII form
,	displayName				VARCHAR(255) NOT NULL
								-- original domain name as was created
,	dns_zone				ENUM('false','true') NOT NULL DEFAULT 'true'
								-- is dns zone for domain exists ?
,	dns_type				ENUM('slave','master') NOT NULL DEFAULT 'master'
								-- dns type for domain
,	status					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- bitmask of status
,	htype					ENUM('none','vrt_hst','std_fwd','frm_fwd') NOT NULL
								-- hosting type on domain
,	real_size				BIGINT UNSIGNED DEFAULT 0
								-- disk space occuppied
,	cl_id					INT UNSIGNED NOT NULL
								-- client ID - domain owner
,	cert_rep_id				INT UNSIGNED
								-- certificate repository ID
,	limits_id				INT UNSIGNED
								-- Limits object ID
,	params_id				INT UNSIGNED
								-- Parameters object ID
,							UNIQUE (name)
,							UNIQUE (displayName)
,							INDEX (cl_id)
								-- REFERENCES clients (id)
,							INDEX (cert_rep_id)
								-- REFERENCES Repository (rep_id)
,							INDEX (limits_id)
								-- REFERENCES Limits (id)
,							INDEX (params_id)
								-- REFERENCES Parameters (id)
) TYPE=InnoDB;

-- domains parameters table
CREATE TABLE dom_param (
	dom_id					INT UNSIGNED NOT NULL
								-- domain ID
,	param					VARCHAR(245) NOT NULL
								-- parameter name
,	val						VARCHAR(255)
								-- parameter value
,							PRIMARY KEY (dom_id, param)
) TYPE=InnoDB;

-- subdomains table
CREATE TABLE subdomains (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- wu ID
,	dom_id					INT UNSIGNED NOT NULL
								-- domain ID
,	name					VARCHAR(255) NOT NULL
								-- subdomain name
,	displayName				VARCHAR(255) NOT NULL
								-- original subdomain name as was created
,	sys_user_type			ENUM('main','native') NOT NULL DEFAULT 'main'
								-- system user type
,	sys_user_id				INT UNSIGNED NOT NULL
								-- sys_user ID
,	ssi						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Server Side Includes support
,	php						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- PHP support
,	cgi						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- CGI support
,	perl					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- PERL support
,	python					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- PYTHON support
,	coldfusion				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- ColdFusion support
,	asp						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- ASP support
,	asp_dot_net				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- ASP.NET support
,							UNIQUE (dom_id, name)
,							UNIQUE (dom_id, displayName)
,							INDEX (sys_user_id)
								-- REFERENCES sys_users (id)
) TYPE=InnoDB;

-- domain services table
CREATE TABLE DomainServices (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- domain service ID
,	dom_id					INT UNSIGNED NOT NULL
								-- domain ID
,	type					ENUM('mail', 'tomcat', 'maillists')
								-- domain service type
,	status					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- domain service status (on/off)
,	parameters_id			INT UNSIGNED
								-- parameters object ID
,							INDEX (dom_id)
								-- REFERENCES domains (id)
,							INDEX (parameters_id)
								-- REFERENCES Parameters (id)
) TYPE=InnoDB;

-- Web Applications table
CREATE TABLE WebApps (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- webapp ID
,	name					VARCHAR(255)
								-- webapp name
,	status					INT NOT NULL DEFAULT 0
								-- webapp status (on/off)
,	domain_service_id		INT UNSIGNED NOT NULL
								-- domain service object ID
,							INDEX (domain_service_id)
								-- REFERENCES DomainServices (id)
) TYPE=InnoDB;

-- domains disk usage information
CREATE TABLE disk_usage (
	dom_id					INT UNSIGNED PRIMARY KEY
								-- domain ID
,	httpdocs				BIGINT UNSIGNED DEFAULT 0
								-- space used by http documents
,	httpsdocs				BIGINT UNSIGNED DEFAULT 0
								-- space used by https documents
,	subdomains				BIGINT UNSIGNED DEFAULT 0
								-- space used by subdomains
,	web_users				BIGINT UNSIGNED DEFAULT 0
								-- space used by web users
,	anonftp					BIGINT UNSIGNED DEFAULT 0
								-- space used by anonymous ftp directory
,	logs					BIGINT UNSIGNED DEFAULT 0
								-- space used by domain logs directory
,	dbases					BIGINT UNSIGNED DEFAULT 0
								-- space used by domain databases
,	mailboxes				BIGINT UNSIGNED DEFAULT 0
								-- space used by domain mail boxes
,	webapps					BIGINT UNSIGNED DEFAULT 0
								-- space used by domain servlets & JSPs
,	maillists				BIGINT UNSIGNED DEFAULT 0
								-- space used by maillists
,	domaindumps				BIGINT UNSIGNED DEFAULT 0
								-- space used by domain dumps
) TYPE=InnoDB;

-- components list for statistic page
CREATE TABLE Components (
	name					VARCHAR(255) PRIMARY KEY
,	version					VARCHAR(255)
) TYPE=InnoDB;

------------------------------------------------------------------------
---- DNS section

-- DNS Resource Records
CREATE TABLE dns_recs (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- DNS RR ID
,	dom_id					INT UNSIGNED
								-- domain ID
,	type					ENUM('NS','A','CNAME','MX','PTR','TXT','none') NOT NULL DEFAULT 'A'
								-- RR type
,	host					VARCHAR(255) NOT NULL
								-- left column in zone file
,	val						VARCHAR(255) NOT NULL
								-- right column in zone file
,	opt						VARCHAR(255) NOT NULL DEFAULT ''
								-- options (preferences for MX, mask for PTR)
,	time_stamp				TIMESTAMP(14) NOT NULL
,							INDEX (type)
,							INDEX (dom_id)
								-- REFERENCES domains (id)
) TYPE=InnoDB;

-- Master DNS servers
CREATE TABLE dns_masters (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- DNS RR ID
,	dom_id					INT UNSIGNED NOT NULL
								-- domain ID
,	ip_address				VARCHAR(255) NOT NULL
								-- IPs of master DNS servers
,							UNIQUE (dom_id, ip_address)
) TYPE=InnoDB;

-- DNS Resource Records Template
CREATE TABLE dns_recs_t (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- DNS RR ID
,	type					ENUM('NS','A','CNAME','MX','PTR','TXT','none') NOT NULL DEFAULT 'A'
								-- RR type
,	host					VARCHAR(255) NOT NULL
								-- left column in zone file
,	val						VARCHAR(255) NOT NULL
								-- right column in zone file
,	opt						VARCHAR(255) NOT NULL DEFAULT ''
								-- options (preferences for MX, mask for PTR)
,	time_stamp				TIMESTAMP(14) NOT NULL
) TYPE=InnoDB;

------------------------------------------------------------------------
---- Hosting section

-- physical hosting table
CREATE TABLE hosting (
	dom_id					INT UNSIGNED PRIMARY KEY
								-- domain ID
,	sys_user_id				INT UNSIGNED NOT NULL
								-- sys_user ID
,	ip_address_id			INT UNSIGNED NOT NULL
								-- hosting IP address
,	real_traffic			BIGINT UNSIGNED DEFAULT 0
								-- real http traffic from month start
,	fp						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- FrontPage support
,	fp_ssl					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- FrontPage over SSL support
,	fp_enable				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- FP authorization enable/disable
,	fp_adm					CHAR(16) NOT NULL
								-- admin login for FP
,	fp_pass					CHAR(20) NOT NULL
								-- admin password for FP
,	ssi						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Server Side Includes support
,	php						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- PHP support
,	cgi						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- CGI support
,	perl					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- PERL support
,	python					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- PYTHON support
,	coldfusion				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- ColdFusion support
,	asp						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- ASP support
,	asp_dot_net				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- ASP.NET support
,	`ssl`						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- SSL support
,	webstat					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Webstat support
,	at_domains				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- @-domains support
,	same_ssl				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- common context for ssl & non-ssl hosting
,							UNIQUE (sys_user_id)
								-- REFERENCES sys_users (id)
,							INDEX (ip_address_id)
								-- REFERENCES IP_Addresses (id)
) TYPE=InnoDB;

--	webusers (wu) table (example: www.yahoo.com/~kan)
CREATE TABLE web_users (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- wu ID
,	dom_id					INT UNSIGNED NOT NULL
								-- domain ID
,	sys_user_id				INT UNSIGNED NOT NULL
								-- sys_user ID
,	ssi						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Server Side Includes support
,	php						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- PHP support
,	cgi						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- CGI support
,	perl					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- PERL support
,	python					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- PYTHON support
,	asp						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- ASP support
,	asp_dot_net				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- ASP.NET support
,							INDEX (dom_id)
								-- REFERENCES domains (id)
,							UNIQUE (sys_user_id)
								-- REFERENCES sys_users (id)
) TYPE=InnoDB;

-- password protected directories table (PPD)
CREATE TABLE protected_dirs (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- PPD ID
,	non_ssl					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- which tree used for PPD (httpdocs)
,	`ssl`						ENUM('false','true') NOT NULL DEFAULT 'false'
								-- which tree used for PPD (httpsdocs)
,	realm					VARCHAR(255)
								-- Header text
,	path					VARCHAR(245) BINARY NOT NULL
								-- directory name (path)
,	dom_id					INT UNSIGNED NOT NULL
								-- domain ID
,							UNIQUE (dom_id, path)
) TYPE=InnoDB;

-- PPD users
CREATE TABLE pd_users (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- PPD user ID
,	login					CHAR(20) BINARY NOT NULL
								-- PPD user login
,	account_id				INT UNSIGNED NOT NULL
								-- account id
,	pd_id					INT UNSIGNED NOT NULL
								-- PPD ID
,							INDEX (account_id)
								-- REFERENCES accounts (id)
,							UNIQUE (pd_id, login)
) TYPE=InnoDB;

-- logrotation configuration
CREATE TABLE log_rotation (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- log rotation record ID, autogenerated
,	period_type				ENUM('by_time','by_size') NOT NULL DEFAULT 'by_time'
								-- type of log rotation period
,	period					VARCHAR(50)
								-- log rotation period
,	max_number_of_logfiles	BIGINT UNSIGNED DEFAULT 0
								-- max number of logfiles
,	compress_enable			ENUM('false','true') NOT NULL DEFAULT 'false'
								-- enable or disable logfiles compression
,	email					VARCHAR(255)
								-- email address for rotated logfile sending
,	turned_on				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- enable or disable log rotation service
) TYPE=InnoDB;

-- destination URLs for standard forwarding && frame forwarding
CREATE TABLE forwarding (
	dom_id					INT UNSIGNED PRIMARY KEY
								-- domain ID
,	ip_address_id			INT UNSIGNED NOT NULL
,	redirect				VARCHAR(255)
								-- destination URL
,							INDEX (ip_address_id)
								-- REFERENCES IP_Addresses (id)
) TYPE=InnoDB;

-- anonymous virtual FTP domain information
CREATE TABLE anon_ftp (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	dom_id					INT UNSIGNED NOT NULL
,	max_conn				INT UNSIGNED
								-- maximum connections limit
,	bandwidth				INT UNSIGNED
								-- bandwidth limit
,	incoming				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Turn incoming on or off
,	incoming_readable		ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Is incoming directory readable
,	incoming_subdirs		ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Enable create subdirs in incoming
,	status					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Turn anonymous virtual FTP domain on/off
,	quota					BIGINT UNSIGNED DEFAULT 1048576
								-- Incoming directory quota
,	display_login			ENUM('false','true') NOT NULL DEFAULT 'false'
								-- is display login message enable
,	login_text				TEXT
								-- login message text
,							UNIQUE (dom_id)
								-- REFERENCES domains (id)
) TYPE=InnoDB;

------------------------------------------------------------------------
---- Traffic section

-- daily traffic statistics for Domains
CREATE TABLE DomainsTraffic (
	dom_id					INT UNSIGNED NOT NULL
								-- domain ID
,	date					DATE NOT NULL
								-- date
,	http_in					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- http(s) input traffic in bytes for this data
,	http_out				BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- http(s) output traffic in bytes for this data
,	ftp_in					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- ftp(s) input traffic in bytes for this data
,	ftp_out					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- ftp(s) output traffic in bytes for this data
,	smtp_in					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- smtp(s) input traffic in bytes for this data
,	smtp_out				BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- smtp(s) output traffic in bytes for this data
,	pop3_imap_in			BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- pop3(s)/imap(s) input traffic in bytes for this data
,	pop3_imap_out			BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- pop3(s)/imap(s) output traffic in bytes for this data
,							PRIMARY KEY (dom_id, date)
) TYPE=InnoDB;

-- daily traffic statistics for Clients
CREATE TABLE ClientsTraffic (
	cl_id					INT UNSIGNED NOT NULL
								-- client id
,	date					DATE NOT NULL
								-- date
,	http_in					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- http(s) input traffic in bytes for this data
,	http_out				BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- http(s) output traffic in bytes for this data
,	ftp_in					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- ftp(s) input traffic in bytes for this data
,	ftp_out					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- ftp(s) output traffic in bytes for this data
,	smtp_in					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- smtp(s) input traffic in bytes for this data
,	smtp_out				BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- smtp(s) output traffic in bytes for this data
,	pop3_imap_in			BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- pop3(s)/imap(s) input traffic in bytes for this data
,	pop3_imap_out			BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- pop3(s)/imap(s) output traffic in bytes for this data
,							PRIMARY KEY (cl_id, date)
) TYPE=InnoDB;

------------------------------------------------------------------------
---- Certificates section

CREATE TABLE certificates (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	csr						BLOB NOT NULL DEFAULT ''
								-- CSR
,	pvt_key					BLOB NOT NULL DEFAULT ''
								-- Certificate private key
,	cert					BLOB NOT NULL DEFAULT ''
								-- Certificate body
,	cert_file				VARCHAR(255) NOT NULL DEFAULT ''
								-- Certificate file name
,	ca_cert					BLOB NOT NULL DEFAULT ''
								-- CA certificate
,	ca_file					VARCHAR(255) NOT NULL DEFAULT ''
								-- CA certificate file name
,	name					VARCHAR(255) NOT NULL DEFAULT ''
								-- Certificate name
) TYPE=InnoDB;

------------------------------------------------------------------------
---- Mail section

-- mail names table (mn)
CREATE TABLE mail (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- mn ID
,	mail_name				VARCHAR(245) NOT NULL
								-- mail name
,	cp_access				ENUM('true','false') NOT NULL DEFAULT 'true'
								-- control panel access
,	postbox					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- is postbox created ?
,	account_id				INT UNSIGNED NOT NULL
								-- account id
,	redirect				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- is mail redirect created ?
,	redir_addr				VARCHAR(255)
								-- redirect destination (e-mail address)
,	mail_group				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- is mail group created ?
,	autoresponder			ENUM('false','true') NOT NULL DEFAULT 'false'
								-- is autoresponders enabled on mailname ?
,	mbox_quota				BIGINT DEFAULT -1 NOT NULL
,	dom_id					INT UNSIGNED NOT NULL
								-- domain ID
,							INDEX (account_id)
								-- REFERENCES accounts (id)
,							UNIQUE (dom_id, mail_name)
) TYPE=InnoDB;

-- mail alias table
CREATE TABLE mail_aliases (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- ID
,	mn_id					INT UNSIGNED NOT NULL
								-- mailname ID
,	alias					VARCHAR(245) NOT NULL
								-- mail alias name
,							UNIQUE (mn_id, alias)
) TYPE=InnoDB;

-- mail group members table (mg_mem)
CREATE TABLE mail_redir (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- mg_mem ID
,	mn_id					INT UNSIGNED NOT NULL
								-- mn ID
,	address					VARCHAR(245) NOT NULL
								-- e-mail address of mail group member
,							UNIQUE (mn_id, address)
) TYPE=InnoDB;

-- autoresponders table
CREATE TABLE mail_resp (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- autoresponder ID
,	mn_id					INT UNSIGNED NOT NULL
								-- mail name ID
,	resp_name				VARCHAR(245) NOT NULL
								-- autoresponder name
,	keystr					VARCHAR(255)
								-- request string (ex: "send price list")
,	key_where				ENUM('subj','body','no') NOT NULL DEFAULT 'no'
								-- request place
,	subject					VARCHAR(255)
								-- respond with this Subject:
,	reply_to				VARCHAR(255)
								-- respond with this Reply-To:
,	content_type			VARCHAR(245) NOT NULL DEFAULT 'text/plain'
								-- text content_type
,	charset					VARCHAR(245) NOT NULL DEFAULT 'UTF-8'
								-- text codepage
,	text					MEDIUMTEXT
								-- respond with this text
,	resp_on					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- is the responder on?
,	ans_freq				INT DEFAULT 10
								-- (default was 86400) responses in one day
,	mem_limit				INT DEFAULT 1000
								-- number of records in resp_freq for this responder
,							UNIQUE (mn_id, resp_name)
) TYPE=InnoDB;

-- number of responses from email	TEMP
CREATE TABLE resp_freq (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	rn_id					INT UNSIGNED NOT NULL
,	email					VARCHAR(245) NOT NULL
								-- requester email
,	num						INT DEFAULT 0
								-- number of requests in this day
,	time_resp				TIMESTAMP(14) NOT NULL
,							UNIQUE (rn_id, email)
) TYPE=InnoDB;

-- attachments files for autoresponders
CREATE TABLE resp_attach (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- file ID
,	rn_id					INT UNSIGNED NOT NULL
								-- autoresponder ID
,	filename				VARCHAR(245) NOT NULL
								-- attachment file name
,							UNIQUE (rn_id, filename)
) TYPE=InnoDB;

-- request forwarding addresses for autoresponders
CREATE TABLE resp_forward (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- ID
,	rn_id					INT UNSIGNED NOT NULL
								-- autoresponder ID
,	address					VARCHAR(245) NOT NULL
								-- email address to redirect request
,							UNIQUE (rn_id, address)
) TYPE=InnoDB;

-- used for SMTP poplocks and IP white list for relay
CREATE TABLE smtp_poplocks (
	ip_address				CHAR(15) NOT NULL
								-- IP address
,							INDEX (ip_address)
,	ip_mask					INT UNSIGNED NOT NULL DEFAULT 32
								-- IP mask
,	lock_time				DATETIME
								-- lock time
) TYPE=InnoDB;

-- mail parameters table (temporary table for skin and language save)
CREATE TABLE mn_param (
	mn_id					INT UNSIGNED NOT NULL
								-- mail name id
,	param					VARCHAR(245) NOT NULL
								-- parameter name
,	val						VARCHAR(255)
								-- parameter value
,							PRIMARY KEY (mn_id, param)
) TYPE=InnoDB;

-- badmailfrom table
CREATE TABLE badmailfrom (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- ID
,	domain					VARCHAR(255) NOT NULL
								-- domain name
,							UNIQUE (domain)
) TYPE=InnoDB;

------------------------------------------------------------------------
---- Notifications section

-- Notifications table
CREATE TABLE Notifications (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- Notification ID
,	status					CHAR(1)	NOT NULL
								-- Notification status (on/off)
,	send2admin				CHAR(1)	NOT NULL
								-- Send notification to admin ?
,	send2client				CHAR(1)	NOT NULL
								-- Send notification to client ?
,	send2dlu				CHAR(1)	NOT NULL
								-- Send notification to domain level user ?
,	send2email				CHAR(1)	NOT NULL
								-- Send notification to the email ?
,	email					VARCHAR(255) NOT NULL
								-- Email address
,	subj					VARCHAR(255) NOT NULL
								-- Notification subject field
,	note_id					INT	UNSIGNED
								-- Respected note ID
,							INDEX (note_id)
								-- REFERENCES Notes (id)
) TYPE=InnoDB;

-- Note table
CREATE TABLE Notes (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- Note ID
,	text					TEXT NOT NULL
								-- Note text
) TYPE=InnoDB;

------------------------------------------------------------------------
---- Sessions section

CREATE TABLE sessions (
	sess_id					CHAR(33) PRIMARY KEY
								-- cookie value
,	type					SMALLINT UNSIGNED NOT NULL
								-- session type (IS_ADMIN, IS_RESELLER, IS_CLIENT...)
,	login					VARCHAR(255) NOT NULL
,	ip_address				CHAR(15) NOT NULL
								-- IP Address number in a dot notation
,	login_time				DATETIME NOT NULL
,	click_time				TIMESTAMP NOT NULL
) TYPE=InnoDB;

--	list supported interface languages
CREATE TABLE locales (
	id						VARCHAR(17) PRIMARY KEY
								-- lang ID (IETF RFC 1766): "en-US", "ru-RU", etc
,	active					ENUM('false', 'true') NOT NULL DEFAULT 'true'
) TYPE=InnoDB;

-- table for lockout/timeout management	TEMP
CREATE TABLE lockout (
	login					VARCHAR(20) PRIMARY KEY
								-- plesk login name
,	last_wrong				TIMESTAMP(14) NOT NULL
								-- time of last wrong login attempt
,	attempts				INT NOT NULL DEFAULT 1
								-- number of wrong attempts
) TYPE=InnoDB;

-- Logos tables
CREATE TABLE Logos (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- ID
,	name					VARCHAR(255)
,	fake					VARCHAR(255)
,	url						VARCHAR(255)
,	showMode				VARCHAR(255)
) TYPE=InnoDB;

------------------------------------------------------------------------
---- Databases section

CREATE TABLE data_bases (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	name					CHAR(32) BINARY NOT NULL
,	type					ENUM('mysql', 'postgresql', 'mssql') NOT NULL DEFAULT 'mysql'
,	dom_id					INT UNSIGNED NOT NULL
,							UNIQUE (name, type)
,							INDEX (dom_id)
								-- REFERENCES domains (id)
) TYPE=InnoDB;

CREATE TABLE db_users (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	login					CHAR(16) BINARY NOT NULL
,	account_id				INT UNSIGNED NOT NULL
,	db_id					INT UNSIGNED NOT NULL
,							UNIQUE (db_id, login)
,							INDEX (account_id)
								-- REFERENCES accounts (id)
) TYPE=InnoDB;

------------------------------------------------------------------------
---- Objects section

-- Cards table
CREATE TABLE Cards (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- ID, autogenerated
,	personalName			VARCHAR(255) NOT NULL
								-- personal name
,	companyName				VARCHAR(255)
								-- company name
,	phone					VARCHAR(255)
								-- contact phone
,	fax						VARCHAR(255)
								-- contact fax
,	email					VARCHAR(255)
								-- contact e-mail
,	address					VARCHAR(255)
								-- address
,	city					VARCHAR(255)
								-- city
,	state					VARCHAR(255)
								-- state
,	zip						CHAR(10)
								-- postoffice code
,	country					CHAR(2)
								-- country
) TYPE=InnoDB;

-- System users
CREATE TABLE sys_users (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- sys_user ID, autogenerated
,	login					VARCHAR(20) NOT NULL
								-- system user login
,	account_id					INT UNSIGNED NOT NULL
								-- account id
,	home					VARCHAR(255) NOT NULL
								-- system user home directory
,	shell					VARCHAR(255) NOT NULL
								-- system user shell
,	quota					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- disk space hard limitation(MBytes)
,							UNIQUE (login)
								-- unique index on login
,							INDEX (account_id)
								-- REFERENCES accounts (id)
) TYPE=InnoDB;

-- permissions table
CREATE TABLE Permissions (
	id						INT UNSIGNED AUTO_INCREMENT NOT NULL
,	permission				CHAR(245) NOT NULL
,	value					CHAR(255)
,							PRIMARY KEY (id, permission)
) TYPE=InnoDB;

-- parameters table
CREATE TABLE Parameters (
	id						INT UNSIGNED AUTO_INCREMENT NOT NULL
,	parameter				CHAR(245) NOT NULL
,	value					CHAR(255)
,							PRIMARY KEY (id, parameter)
) TYPE=InnoDB;

-- limits table
CREATE TABLE Limits (
	id						INT UNSIGNED AUTO_INCREMENT NOT NULL
,	limit_name				CHAR(245) NOT NULL
,	value					CHAR(255)
,							PRIMARY KEY (id, limit_name)
) TYPE=InnoDB;

-- template table
CREATE TABLE Templates (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- tmpl ID, autogenerated
,	name					CHAR(255) NOT NULL
,	note_id					INT	UNSIGNED
								-- Respected note ID
,							INDEX (note_id)
								-- REFERENCES Notes (id)
) TYPE=InnoDB;

-- template data table
CREATE TABLE TmplData (
	tmpl_id					INT UNSIGNED NOT NULL
,	element					CHAR(245) NOT NULL
,	value					CHAR(255) NOT NULL
,							PRIMARY KEY (tmpl_id, element)
) TYPE=InnoDB;

-- Identifiers repository
CREATE TABLE Repository (
	rep_id					INT UNSIGNED AUTO_INCREMENT NOT NULL
,	component_id			INT UNSIGNED NOT NULL
,							PRIMARY KEY (rep_id, component_id)
) TYPE=InnoDB;

-- skins table
CREATE TABLE Skins (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- skin ID, autogenerated
,	name					VARCHAR(255) NOT NULL
								-- name of skin
,	place					CHAR(255) NOT NULL
								-- skin directory
,							UNIQUE (name)
,							UNIQUE (place)
) TYPE=InnoDB;

------------------------------------------------------------------------
---- Enterprise section

-- slave hosts
CREATE TABLE slaves (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- ID
,	hostname				VARCHAR(255) NOT NULL
,							UNIQUE (hostname)
) TYPE=InnoDB;

-- slave hosts parameters
CREATE TABLE slave_params (
	slave_id				INT UNSIGNED NOT NULL
,	parameter				VARCHAR(245) NOT NULL
,	value					VARCHAR(255) NOT NULL
,							PRIMARY KEY (slave_id, parameter)
) TYPE=InnoDB;

------------------------------------------------------------------------
---- Miscellaneous section

-- miscellaneous parameters (see end of this script)
CREATE TABLE misc (
	param					VARCHAR(255) NOT NULL PRIMARY KEY
								-- parameter name
,	val						VARCHAR(255) NOT NULL
								-- parameter value
) TYPE=InnoDB;

-- Client-mailer queries list
CREATE TABLE mailer_queries (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- ID
,	query					TEXT NOT NULL
,	description				VARCHAR(100) NOT NULL
,	locale_key				VARCHAR(20) NOT NULL DEFAULT ''
) TYPE=InnoDB;

-- Custom buttons
CREATE TABLE custom_buttons (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	sort_key				INT UNSIGNED NOT NULL DEFAULT 100
								-- sort key
,	level					INT UNSIGNED NOT NULL DEFAULT 0
								-- level
,	level_id				INT UNSIGNED NOT NULL DEFAULT 0
								-- level id
,	place					ENUM('domain', 'client', 'navigation') NOT NULL DEFAULT 'domain'
,	text					VARCHAR(255) NOT NULL
,	url						VARCHAR(255)
,	conhelp					TEXT
,	options					INT UNSIGNED NOT NULL DEFAULT 0
,	file					VARCHAR(245) NOT NULL
								-- image file name
) TYPE=InnoDB;

-- Control visibility customizations
CREATE TABLE ControlVisibility (
	page					VARCHAR(127) NOT NULL
								-- page on which the control is
,	control					VARCHAR(127) NOT NULL
								-- control ID
,	state					ENUM('hide', 'adminOnly', 'show') NOT NULL DEFAULT 'hide'
								-- custom visibility
,	control_type			ENUM('button', 'formControl') NOT NULL DEFAULT 'button'
								-- type of control
,							PRIMARY KEY (page, control)
) TYPE=InnoDB;

-- PSA Upgrade history
CREATE TABLE upgrade_history (
	upgrade_date			DATETIME PRIMARY KEY
,	version_info			VARCHAR(50) NOT NULL
,	db_version				VARCHAR(8) NOT NULL
) TYPE=InnoDB;

-- Interfaces lists parameters (page, sort, filter)
CREATE TABLE ListsParams (
	user_id					INT UNSIGNED NOT NULL DEFAULT 0
								-- current session user id (client id now)
,	user_type				INT UNSIGNED NOT NULL DEFAULT 0
								-- current session user type
,	parentList_id			INT	UNSIGNED NOT NULL DEFAULT 0
								-- list owner id (0 for domain independent lists)
,	list_name				VARCHAR(225) NOT NULL DEFAULT ''
								-- list class name (ex: DomainsList)
,	flags					INT UNSIGNED NOT NULL DEFAULT 0
								-- list optionsl bitmask bits from 0 to 4 - optional flags,
								-- bits from 5 - expand status of columns
,	sort					VARCHAR(255) NOT NULL DEFAULT 'name'
								-- column name for sorting (ex: name[_reverse])
,	filter					VARCHAR(255) NOT NULL DEFAULT ''
								-- search filter
,	page					INT NOT NULL DEFAULT 0
								-- current page number
,	page_size				INT NOT NULL DEFAULT 25
								-- preferred number of items per page
,							PRIMARY KEY (user_id, user_type, parentList_id, list_name)
) TYPE=InnoDB;

-- Server IP addresses
CREATE TABLE IP_Addresses (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- IP Address ID
,	ip_address				CHAR(15) NOT NULL
								-- IP Address number in a dot notation
,	mask					CHAR(15) NOT NULL DEFAULT '255.255.255.0'
,	iface					VARCHAR(255) NOT NULL
,	type					ENUM('shared','exclusive') NOT NULL DEFAULT 'shared'
								-- IP Address type: shared or exclusive
,	ssl_certificate_id		INT UNSIGNED NOT NULL
								-- SSL Certificate ID
,	default_domain_id		INT UNSIGNED
								-- default hosting ID (really dom_id)
,							UNIQUE (ip_address)
,							INDEX (ssl_certificate_id)
								-- REFERENCES certificates (id)
,							INDEX (default_domain_id)
								-- REFERENCES hosting (dom_id) ON DELETE SET NULL
) TYPE=InnoDB;

------------------------------------------------------------------------
---- Action Log section

-- List of logable actions: name (for php), descr (human-readable), enabled (bool)
CREATE TABLE actions (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- Action ID
,	name					VARCHAR(255) NOT NULL
								-- Action Name
,	descr					VARCHAR(255) NOT NULL
								-- Action Description
,	enabled					ENUM ('false', 'true') NOT NULL DEFAULT 'true'
								-- Status: enabled/disabled
,							UNIQUE (name)
) TYPE=InnoDB;

-- Action Log Content (Action)
CREATE TABLE log_actions (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- Action ID
,	date					DATETIME NOT NULL
								-- Action date
,	ip_address				CHAR(15) NOT NULL
								-- IP from which was established connection
,	user					VARCHAR(255) NOT NULL
								-- Control Panel user login name
,	action_id				INT UNSIGNED NOT NULL
								-- Action ID
,	object_id				INT UNSIGNED NOT NULL
								-- Identifies operated object (interaction with BS)
,							INDEX (action_id)
								-- REFERENCES actions (id)
) TYPE=InnoDB;

-- Action Log Content (Components)
CREATE TABLE log_components (
	action_id				INT UNSIGNED NOT NULL
								-- Action ID
,	component				VARCHAR(245) NOT NULL
								-- Component
,	old_value				VARCHAR(255) NOT NULL
								-- Old value
,	new_value				VARCHAR(255) NOT NULL
								-- New value
,							PRIMARY KEY (action_id, component)
) TYPE=InnoDB;

-- event handlers table
CREATE TABLE event_handlers (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- event handler ID
,	action_id				INT UNSIGNED NOT NULL
								-- action ID
,	priority				INT UNSIGNED NOT NULL DEFAULT 0
,	user					VARCHAR(255) NOT NULL DEFAULT 'nobody'
								-- system user name
,	command					TEXT NOT NULL
								-- command string with parameters
,							INDEX (action_id)
								-- REFERENCES actions (id)
) TYPE=InnoDB;

------------------------------------------------------------------------
---- Mail lists section

-- mail lists table
CREATE TABLE MailLists (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- MailList ID, autogenerated
,	dom_id					INT UNSIGNED NOT NULL
								-- Domain ID, reference to domain id
,	name					VARCHAR(255) NOT NULL
								-- MailList name
,	status					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- MailList status bitmask
,							INDEX (dom_id)
								-- REFERENCES domains (id)
) TYPE=InnoDB;

------------------------------------------------------------------------
---- IP Access restriction section

-- IP access restriction table
CREATE TABLE cp_access (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- IP Access record id, autogenerated
,	type					ENUM('allow', 'deny') NOT NULL DEFAULT 'allow'
								-- cp acces table type
,	netaddr					CHAR(15) NOT NULL
								-- IP Address
,	netmask					CHAR(15) NOT NULL
								-- IP Netmask
) TYPE=InnoDB;

------------------------------------------------------------------------
---- Reports section

CREATE TABLE report (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	type					INT UNSIGNED NOT NULL
								-- IS_CLIENT or IS_DOMAIN_OWNER
,	user_id					INT UNSIGNED NOT NULL DEFAULT 0
,	user_type				INT UNSIGNED NOT NULL
								-- IS_ADMIN or IS_CLIENT or IS_DOMAIN_OWNER
,	name					VARCHAR(255) NOT NULL
,	is_default				ENUM('false','true') NOT NULL DEFAULT 'false'
) TYPE=InnoDB;

CREATE TABLE report_section (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	report_id				INT UNSIGNED NOT NULL
,	name					VARCHAR(255) NOT NULL
,	type					ENUM('none','summary','full') NOT NULL DEFAULT 'summary'
,							INDEX (report_id)
								-- REFERENCES report (id)
) TYPE=InnoDB;

CREATE TABLE report_auto (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	report_id				INT UNSIGNED NOT NULL
,	auto					INT UNSIGNED NOT NULL DEFAULT 0
,	last					DATETIME DEFAULT NULL
,	recipient				INT UNSIGNED NOT NULL DEFAULT 0
,	email					VARCHAR(254) NOT NULL
,	client					INT UNSIGNED
,	domain					INT UNSIGNED
,							INDEX (report_id)
								-- REFERENCES report (id)
,							INDEX (client)
								-- REFERENCES clients (id)
,							INDEX (domain)
								-- REFERENCES domains (id)
) TYPE=InnoDB;

------------------------------------------------------------------------
---- Extensions (Modules) section

-- modules table
CREATE TABLE Modules (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- ID, autogenerated
,	name					VARCHAR(255) BINARY NOT NULL
								-- module name
,	packname				VARCHAR(255) BINARY NOT NULL
								-- package name (probably the same as name)
,	display_name			VARCHAR(255) BINARY NOT NULL
								-- is display module name
,	version					VARCHAR(30) BINARY NOT NULL
								-- version
,	release					INT UNSIGNED NOT NULL
								-- release
,	description				VARCHAR(255)
,	icon					VARCHAR(255) BINARY NOT NULL
,							UNIQUE (name)
) TYPE=InnoDB;

------------------------------------------------------------------------
---- CGI applications section

CREATE TABLE SiteAppPackages (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- application id
,	name					VARCHAR(255) BINARY NOT NULL
								-- short name
,	version					VARCHAR(30) BINARY NOT NULL
								-- version
,	release					VARCHAR(30) BINARY NOT NULL
								-- release
,	description				VARCHAR(255)
								-- description
,	access_level			INT UNSIGNED NOT NULL DEFAULT 0
								-- necessary access level to install application
,	integrated				ENUM('false', 'true') NOT NULL DEFAULT 'false'
								-- integrated in Plesk
,							UNIQUE (name, version, release)
) TYPE=InnoDB;

CREATE TABLE SiteApps (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- installed application id
,	dom_id					INT UNSIGNED NOT NULL
								-- reference to domain, where application is installed
,	dom_type				ENUM('domain', 'subdomain') NOT NULL DEFAULT 'domain'
								-- where application is installed
,	install_prefix			VARCHAR(255) BINARY NOT NULL
								-- directory of application inside vhost
,	htdocs_directory		ENUM('httpdocs', 'httpsdocs') NOT NULL DEFAULT 'httpdocs'
								-- which documents tree is used for application
,	app_id					INT UNSIGNED NOT NULL
								-- reference to application in repository
,	params_id				INT UNSIGNED
								-- object id with values of parameters
								-- that are used for installed application
,							INDEX (app_id)
								-- REFERENCES SiteAppPackages (id)
,							INDEX (params_id)
								-- REFERENCES Parameters (id)
) TYPE=InnoDB;

CREATE TABLE SiteAppResources (
	app_id					INT UNSIGNED NOT NULL
								-- reference to application
,	type					ENUM('database', 'dbuser', 'custom_button') NOT NULL DEFAULT 'database'
								-- name of type
,	res_id					INT UNSIGNED NOT NULL
								-- reference to resource
,							INDEX (app_id)
								-- REFERENCES SiteApps (id)
,							UNIQUE (type, res_id)
) TYPE=InnoDB;

------------------------------------------------------------------------
---- TTS section

CREATE TABLE tts_queues (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- queue ID, autogenerated
,	enabled					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Is enabled for using
,	title					VARCHAR(255)
								-- queue title
) TYPE=InnoDB;

CREATE TABLE tts_priorities (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- priority ID, autogenerated
,	enabled					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Is enabled for using
,	title					VARCHAR(255)
								-- queue title
) TYPE=InnoDB;

CREATE TABLE tts_cats (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- category ID, autogenerated
,	enabled					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Is enabled for using
,	title					VARCHAR(255)
								-- queue title
) TYPE=InnoDB;

CREATE TABLE tts_conf (
	id						INT UNSIGNED PRIMARY KEY
								-- ID, setuped manualy
,	enabled					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Is enabled for clients
,	can_post				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Allow clients to post tickets
,	def_qu_id				INT UNSIGNED NOT NULL
								-- Default Queue object ID
,	def_pr_id				INT UNSIGNED NOT NULL
								-- Default Priority object ID
,	def_cat_id				INT UNSIGNED NOT NULL
								-- Default Category object ID
,	mg_enabled				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Is mailgate enabled
,	email_address			VARCHAR(255)
								-- Send notifications from email
,	email_name				VARCHAR(255)
								-- Send notifications from name
,	pop_server				VARCHAR(255)
								-- POP3 server name for incoming tickets
,	pop_username			VARCHAR(255)
								-- POP3 login
,	pop_password			VARCHAR(255)
								-- POP3 password
,	query_period			INT UNSIGNED
								-- Period for querying mail (in minutes)
,	start_ticket_subj		VARCHAR(255)
								-- Ticket's subject must start with this prefix (for anti-spam)
,							INDEX (def_qu_id)
								-- REFERENCES tts_queues (id)
,							INDEX (def_pr_id)
								-- REFERENCES tts_priorities (id)
,							INDEX (def_cat_id)
								-- REFERENCES tts_cats (id)
) TYPE=InnoDB;

CREATE TABLE tts_tickets (
	id 						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- Ticket ID, autogenerated
,	reporter_id				INT UNSIGNED NOT NULL
								-- Reporter ID
,	cat_id					INT UNSIGNED NOT NULL
								-- Categories Object ID
,	qu_id					INT UNSIGNED NOT NULL
								-- Queues Object ID
,	pr_id					INT UNSIGNED NOT NULL
								-- Priorities Object ID
,	status					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- Ticket status bitmask
,	subject					VARCHAR(255)
								-- Ticket subject
,	modified_date			DATETIME
								-- Modified date
,							INDEX (reporter_id)
								-- REFERENCES tts_reporters (id)
,							INDEX (cat_id)
								-- REFERENCES tts_cats (id)
,							INDEX (qu_id)
								-- REFERENCES tts_queues (id)
,							INDEX (pr_id)
								-- REFERENCES tts_priorities (id)
) TYPE=InnoDB;

CREATE TABLE tts_reporters (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- Reporter ID, autogenerated
,	ref_reporter_id			INT UNSIGNED
								-- Reference to clients(id), domain
,	type					ENUM('client', 'domain', 'mailname', 'email', 'admin') NOT NULL DEFAULT 'email'
								-- Ticket reporter ty
,	email					VARCHAR(255)
								-- Mail-Client Email
,	name					VARCHAR(255)
								-- Mail-Client Name
) TYPE=InnoDB;

CREATE TABLE tts_ticket_events (
	id 						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- Event ID, autogenerated
,	ticket_id				INT UNSIGNED NOT NULL
								-- Tickets Object ID
,	event_type				BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- Event Type
,	public					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Is visible for customers
,	reporter_id				INT UNSIGNED NOT NULL
								-- Event Reporter ID
,	created_date			DATETIME
								-- Creation date
,	descr					TEXT NOT NULL
								-- Event Description
,							INDEX (ticket_id)
								-- REFERENCES tts_tickets (id)
,							INDEX (reporter_id)
								-- REFERENCES tts_reporters (id)
) TYPE=InnoDB;

CREATE TABLE tts_slave_info (
	server_id				INT UNSIGNED PRIMARY KEY
								-- Slaves ID
,	enabled					ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Is enabled for clients
,	can_post				ENUM('false','true') NOT NULL DEFAULT 'false'
								-- Allow clients to post tickets
,	cnt_new					BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- New tickets
,	cnt_opened				BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- Opened tickets
,	cnt_reopened			BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- Repened tickets
,	cnt_closed				BIGINT UNSIGNED NOT NULL DEFAULT 0
								-- Closed tickets
,	updated_date			DATETIME
								-- Latest Updated Date
) TYPE=InnoDB;

------------------------------------------------------------------------
---- SpamAssassin section

CREATE TABLE sa_conf (
	mailname				VARCHAR(128) PRIMARY KEY
								-- full mailname in form foo@bar.com (empty string in case of server)
,	flt_enabled				ENUM('user','serv', 'both') NOT NULL DEFAULT 'both'
								-- which of filters enabled (for empty mailname, i.e. server,
								-- means enabledness of all users' filters)
,	rw_subject_tag			VARCHAR(255) NOT NULL DEFAULT '*****SPAM*****'
								-- rewrite subject tag (if spam was detected)
,	hits_required			TINYINT(3) NOT NULL DEFAULT 7
								-- hits required for mark email as probably spam
,	spam_action				ENUM('delete','save') NOT NULL DEFAULT 'save'
								-- what to do if spam recognized
) TYPE=InnoDB;

CREATE TABLE sa_list (
	mailname				VARCHAR(128)
								-- full mailname in form foo@bar.com (empty string in case of server)
,	pattern					VARCHAR(255) NOT NULL
								-- shell-like mailsender pattern (From)
,	color					ENUM('black','white', 'gray') NULL
								-- pattern color: black for blacklist, white for whitelist,
								-- gray for ignorelist, null means neither lists (and don't
								-- look for the pattern into common sa_list, common is marked
								-- with an empty mailname)
,							UNIQUE (mailname, pattern, color)
) TYPE=InnoDB;

------------------------------------------------------------------------
---- BackupTasks section

CREATE TABLE BackupTasks (
	id 						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	obj_id					INT UNSIGNED NOT NULL
,	obj_type				ENUM('domain') NOT NULL
,	last_backup				DATETIME NOT NULL
,	backup_period			INT UNSIGNED NOT NULL
,	active					ENUM('true', 'false') NOT NULL
,	processed				ENUM('true', 'false') NOT NULL
,	repository				ENUM('local', 'ftp') NOT NULL
) TYPE=InnoDB;

------------------------------------------------------------------------
---- Key history section

CREATE TABLE key_history (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
,	plesk_key_id			VARCHAR(63)
,	name					VARCHAR(255) BINARY
,	filename				VARCHAR(255) BINARY
,	register_date			TIMESTAMP not NULL
,	update_disabled			ENUM('false', 'true') NOT NULL DEFAULT 'false'
,	options					VARCHAR(255) BINARY
) TYPE=InnoDB;

CREATE TABLE key_history_params (
	key_id					INT UNSIGNED NOT NULL
,	param					VARCHAR(63) NOT NULL
,	val						VARCHAR(255) NOT NULL
,							PRIMARY KEY (key_id, param)
) TYPE=InnoDB;

------------------------------------------------------------------------
---- PMM section

CREATE TABLE PMM (
	param 					VARCHAR(255) PRIMARY KEY
,	val 					VARCHAR(255) NOT NULL
) TYPE=InnoDB;

------------------------------------------------------------------------
---- Webalizer section

-- referrers to hide
CREATE TABLE webalizer_hidden_referrer (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- Record ID, autogenerated
,	dom_id					INT UNSIGNED NOT NULL
								-- Domain ID
,	referrer				VARCHAR(255) NOT NULL
								-- Referrer value
,							INDEX (dom_id)
								-- REFERENCES domains (id)
) TYPE=InnoDB;

-- referrer groups
CREATE TABLE webalizer_group_referrer (
	id						INT UNSIGNED AUTO_INCREMENT PRIMARY KEY
								-- Record ID, autogenerated
,	dom_id					INT UNSIGNED NOT NULL
								-- Domain ID
,	group_name				VARCHAR(255) NOT NULL
								-- Referrer group name
,	referrer				VARCHAR(255) NOT NULL
								-- Referrer value
,							INDEX (dom_id)
								-- REFERENCES domains (id)
) TYPE=InnoDB;

------------------------------------------------------------------------
-- FOREIGN KEY DECLARATIONS --------------------------------------------
------------------------------------------------------------------------

-- TODO: uncomment this when 8.0 development starts.
-- See bug #34654 for details.

-- ALTER TABLE clients ADD FOREIGN KEY (account_id) REFERENCES accounts (id);
-- ALTER TABLE clients ADD FOREIGN KEY (limits_id) REFERENCES Limits (id);
-- ALTER TABLE clients ADD FOREIGN KEY (params_id) REFERENCES Parameters (id);
-- ALTER TABLE clients ADD FOREIGN KEY (perm_id) REFERENCES Permissions (id);
-- ALTER TABLE clients ADD FOREIGN KEY (pool_id) REFERENCES Repository (rep_id);
-- ALTER TABLE clients ADD FOREIGN KEY (logo_id) REFERENCES Logos (id);
-- ALTER TABLE clients ADD FOREIGN KEY (tmpl_id) REFERENCES Repository (rep_id);
-- ALTER TABLE clients ADD FOREIGN KEY (sapp_pool_id) REFERENCES Repository (rep_id);

-- ALTER TABLE cl_param ADD FOREIGN KEY (cl_id) REFERENCES clients (id);

-- ALTER TABLE dom_level_usrs ADD FOREIGN KEY (dom_id) REFERENCES domains (id);
-- ALTER TABLE dom_level_usrs ADD FOREIGN KEY (account_id) REFERENCES accounts (id);
-- ALTER TABLE dom_level_usrs ADD FOREIGN KEY (card_id) REFERENCES Cards (id);
-- ALTER TABLE dom_level_usrs ADD FOREIGN KEY (perm_id) REFERENCES Permissions (id);

-- ALTER TABLE domains ADD FOREIGN KEY (cl_id) REFERENCES clients (id);
-- ALTER TABLE domains ADD FOREIGN KEY (cert_rep_id) REFERENCES Repository (rep_id);
-- ALTER TABLE domains ADD FOREIGN KEY (limits_id) REFERENCES Limits (id);
-- ALTER TABLE domains ADD FOREIGN KEY (params_id) REFERENCES Parameters (id);

-- ALTER TABLE dom_param ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

-- ALTER TABLE subdomains ADD FOREIGN KEY (dom_id) REFERENCES domains (id);
-- ALTER TABLE subdomains ADD FOREIGN KEY (sys_user_id) REFERENCES sys_users (id);

-- ALTER TABLE DomainServices ADD FOREIGN KEY (dom_id) REFERENCES domains (id);
-- ALTER TABLE DomainServices ADD FOREIGN KEY (parameters_id) REFERENCES Parameters (id);

-- ALTER TABLE WebApps ADD FOREIGN KEY (domain_service_id) REFERENCES DomainServices (id);

-- ALTER TABLE disk_usage ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

-- ALTER TABLE dns_recs ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

-- ALTER TABLE dns_masters ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

-- ALTER TABLE hosting ADD FOREIGN KEY (dom_id) REFERENCES domains (id);
-- ALTER TABLE hosting ADD FOREIGN KEY (sys_user_id) REFERENCES sys_users (id);
-- ALTER TABLE hosting ADD FOREIGN KEY (ip_address_id) REFERENCES IP_Addresses (id);

-- ALTER TABLE web_users ADD FOREIGN KEY (dom_id) REFERENCES domains (id);
-- ALTER TABLE web_users ADD FOREIGN KEY (sys_user_id) REFERENCES sys_users (id);

-- ALTER TABLE protected_dirs ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

-- ALTER TABLE pd_users ADD FOREIGN KEY (account_id) REFERENCES accounts (id);
-- ALTER TABLE pd_users ADD FOREIGN KEY (pd_id) REFERENCES protected_dirs (id);

-- ALTER TABLE forwarding ADD FOREIGN KEY (dom_id) REFERENCES domains (id);
-- ALTER TABLE forwarding ADD FOREIGN KEY (ip_address_id) REFERENCES IP_Addresses (id);

-- ALTER TABLE anon_ftp ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

-- ALTER TABLE DomainsTraffic ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

-- ALTER TABLE ClientsTraffic ADD FOREIGN KEY (cl_id) REFERENCES clients (id);

-- ALTER TABLE mail ADD FOREIGN KEY (account_id) REFERENCES accounts (id);
-- ALTER TABLE mail ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

-- ALTER TABLE mail_aliases ADD FOREIGN KEY (mn_id) REFERENCES mail (id);

-- ALTER TABLE mail_redir ADD FOREIGN KEY (mn_id) REFERENCES mail (id);

-- ALTER TABLE mail_resp ADD FOREIGN KEY (mn_id) REFERENCES mail (id);

-- ALTER TABLE resp_freq ADD FOREIGN KEY (rn_id) REFERENCES mail_resp (id);

-- ALTER TABLE resp_attach ADD FOREIGN KEY (rn_id) REFERENCES mail_resp (id);

-- ALTER TABLE resp_forward ADD FOREIGN KEY (rn_id) REFERENCES mail_resp (id);

-- ALTER TABLE mn_param ADD FOREIGN KEY (mn_id) REFERENCES mail (id);

-- ALTER TABLE Notifications ADD FOREIGN KEY (note_id) REFERENCES Notes (id);

-- ALTER TABLE data_bases ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

-- ALTER TABLE db_users ADD FOREIGN KEY (account_id) REFERENCES accounts (id);
-- ALTER TABLE db_users ADD FOREIGN KEY (db_id) REFERENCES data_bases (id);

-- ALTER TABLE sys_users ADD FOREIGN KEY (account_id) REFERENCES accounts (id);

-- ALTER TABLE Templates ADD FOREIGN KEY (note_id) REFERENCES Notes (id);

-- ALTER TABLE TmplData ADD FOREIGN KEY (tmpl_id) REFERENCES Templates (id);

-- ALTER TABLE slave_params ADD FOREIGN KEY (slave_id) REFERENCES slaves (id);

-- ALTER TABLE IP_Addresses ADD FOREIGN KEY (ssl_certificate_id) REFERENCES certificates (id);
-- ALTER TABLE IP_Addresses ADD FOREIGN KEY (default_domain_id) REFERENCES hosting (dom_id) ON DELETE SET NULL;

-- ALTER TABLE log_actions ADD FOREIGN KEY (action_id) REFERENCES actions (id);

-- ALTER TABLE log_components ADD FOREIGN KEY (action_id) REFERENCES log_actions (id);

-- ALTER TABLE event_handlers ADD FOREIGN KEY (action_id) REFERENCES actions (id);

-- ALTER TABLE MailLists ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

-- ALTER TABLE report_section ADD FOREIGN KEY (report_id) REFERENCES report (id);

-- ALTER TABLE report_auto ADD FOREIGN KEY (report_id) REFERENCES report (id);
-- ALTER TABLE report_auto ADD FOREIGN KEY (client) REFERENCES clients (id);
-- ALTER TABLE report_auto ADD FOREIGN KEY (domain) REFERENCES domains (id);

-- ALTER TABLE SiteApps ADD FOREIGN KEY (app_id) REFERENCES SiteAppPackages (id);
-- ALTER TABLE SiteApps ADD FOREIGN KEY (params_id) REFERENCES Parameters (id);

-- ALTER TABLE SiteAppResources ADD FOREIGN KEY (app_id) REFERENCES SiteApps (id);

-- ALTER TABLE tts_conf ADD FOREIGN KEY (def_qu_id) REFERENCES tts_queues (id);
-- ALTER TABLE tts_conf ADD FOREIGN KEY (def_pr_id) REFERENCES tts_priorities (id);
-- ALTER TABLE tts_conf ADD FOREIGN KEY (def_cat_id) REFERENCES tts_cats (id);

-- ALTER TABLE tts_tickets ADD FOREIGN KEY (reporter_id) REFERENCES tts_reporters (id);
-- ALTER TABLE tts_tickets ADD FOREIGN KEY (cat_id) REFERENCES tts_cats (id);
-- ALTER TABLE tts_tickets ADD FOREIGN KEY (qu_id) REFERENCES tts_queues (id);
-- ALTER TABLE tts_tickets ADD FOREIGN KEY (pr_id) REFERENCES tts_priorities (id);

-- ALTER TABLE tts_ticket_events ADD FOREIGN KEY (ticket_id) REFERENCES tts_tickets (id);
-- ALTER TABLE tts_ticket_events ADD FOREIGN KEY (reporter_id) REFERENCES tts_reporters (id);

-- ALTER TABLE tts_slave_info ADD FOREIGN KEY (server_id) REFERENCES slaves (id);

-- ALTER TABLE sa_list ADD FOREIGN KEY (mailname) REFERENCES sa_conf (mailname);

-- ALTER TABLE key_history_params ADD FOREIGN KEY (key_id) REFERENCES key_history (id);

-- ALTER TABLE webalizer_hidden_referrer ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

-- ALTER TABLE webalizer_group_referrer ADD FOREIGN KEY (dom_id) REFERENCES domains (id);

------------------------------------------------------------------------
-- DATA INSERTION ------------------------------------------------------
------------------------------------------------------------------------

replace into mailer_queries (query,description) values ('select email from clients','all clients');

-- replace into locales (id) values('en-US');

-- replace into misc (param,val) values('admin_email', 'user@example-mail.com');
-- replace into misc (param,val) values('NameVirtualHost', '192.168.2.14');
-- replace into misc (param,val) values('def_locale', 'en-US');
REPLACE INTO misc (param,val) VALUES('def_skin_id',		'8');
REPLACE INTO misc (param,val) VALUES('admin_skin_id',	'8');

replace into misc (param,val) values('include_logs', 		'true');
replace into misc (param,val) values('include_databases',	'true');
replace into misc (param,val) values('include_mailboxes',	'true');
replace into misc (param,val) values('include_webapps',		'true');
replace into misc (param,val) values('include_maillists',	'true');
replace into misc (param,val) values('include_domaindumps',	'true');

replace into misc (param,val) values('size_count_type',		'block');

replace into misc (param,val) values('login_timeout', '30');
replace into misc (param,val) values('lock_interval', '3');
replace into misc (param,val) values('lock_attempts', '3');
replace into misc (param,val) values('lock_time', '30');

replace into misc (param,val) values('relay', 'open');
replace into misc (param,val) values('relay', 'closed');
replace into misc (param,val) values('relay', 'auth');
replace into misc (param,val) values('disable_smtp_auth', '0');
replace into misc (param,val) values('disable_pop_auth', '1');
replace into misc (param,val) values('poplock_time', '20');

replace into misc (param,val) values('actionlog_rot_type', 			'by_period');
replace into misc (param,val) values('actionlog_rot_period', 		'day');
replace into misc (param,val) values('actionlog_rot_num_periods', 	'30');
replace into misc (param,val) values('actionlog_rot_num_records', 	'3000');

replace into misc (param,val) values ('latest_apache_restart', NOW());
replace into misc (param,val) values ('restart_apache_interval', 900);

replace into misc (param,val) values('slave_request_timeout', '20');
replace into misc (param,val) values('slave_services_list_with_non_obligatory_status_checking', 'tomcat,postgresql,coldfusion,spamd');
replace into misc (param,val) values('master_services_list_for_obligatory_status_checking', 'pop3,smtp,http,ftp,dns'); -- imap

-- Bug 23703 enable multy login bu defautl
replace into misc (param,val) values('multiply_login', 'true');

replace into dns_recs_t(host, type, val, time_stamp)		values("<domain>.", "NS", "ns.<domain>.", NOW());
replace into dns_recs_t(host, type, val, time_stamp)		values("ns.<domain>.", "A", "<ip>", NOW()+1);
replace into dns_recs_t(host, type, val, time_stamp)		values("<domain>.", "A", "<ip>", NOW()+2);
replace into dns_recs_t(host, type, val, time_stamp)		values("webmail.<domain>.", "A", "<ip>", NOW()+3);
replace into dns_recs_t(host, type, val, opt, time_stamp)	values("<domain>.", "MX", "mail.<domain>.", 10, NOW()+4);
replace into dns_recs_t(host, type, val, time_stamp)		values("mail.<domain>.", "A", "<ip>", NOW()+5);
replace into dns_recs_t(host, type, val, time_stamp)		values("ftp.<domain>.", "CNAME", "<domain>.", NOW()+6);
replace into dns_recs_t(host, type, val, opt, time_stamp)	values("<ip>", "PTR", "<domain>.", 24, NOW()+7);

delete from Notes;
-- change the defaults.php accordingly
replace into Notes (id, text) values (1, "A new client account has been created in Plesk.\nClient's contact name: <client_contact_name>\nClient's login: <client_login>\nClient's password: <password>\nPlesk entry point: https://<hostname>:8443");
replace into Notes (id, text) values (2, "A new domain has been created in Plesk.\nDomain name: <domain>\nClient owner: <client_contact_name>\nDomain IP: <ip>");
replace into Notes (id, text) values (3, "\nLimit has been exceeded on domain '<domain_name>' owned by client '<client_login>' (Contact name '<client_contact_name>'):\nDisk space usage: <disk_usage>\nDisk space limit: <disk_space_limit>\nTraffic: <traffic>\nTraffic limit: <traffic_limit>\n");
replace into Notes (id, text) values (4, "The validity period of the client account '<client_login>' (Contact Name '<client_contact_name>') has expired.\nThe client account and all related domains were deactivated on <expiration_date>.");
replace into Notes (id, text) values (5, "The validity period of the client account '<client_login>' (Contact Name '<client_contact_name>') is about to expire.\nThe client account and all of related domains will be deactivated by <expiration_date> unless the validity period is prolonged.");
replace into Notes (id, text) values (6, "The validity period of the '<domain_name>' domain owned by client '<client_login>' (Contact name '<client_contact_name>') has expired.\nThe domain and all of its services were deactivated on <expiration_date>.");
replace into Notes (id, text) values (7, "The validity period of the '<domain_name>' domain owned by client '<client_login>' (Contact name '<client_contact_name>') is about to expire.\nThe domain and all of its services will be deactivated by <expiration_date> unless the validity period is prolonged.");
replace into Notes (id, text) values (8, "A new ticket with ID <ticket_id> has been submitted to the Help Desk by <reporter> from <server>.\nPlease retain the ticket identification number for future references. Below is a copy of the ticket.\n-----\n<ticket_comment>\n-----");
replace into Notes (id, text) values (9, "Ticket <ticket_id> has been commented by <reporter> from <server>.\nBelow is the comment.\n-----\n<ticket_comment>\n-----");
replace into Notes (id, text) values (10,"Ticket <ticket_id> has been closed by <reporter> from <server>.\nBelow is the comment.\n-----\n<ticket_comment>\n-----");
replace into Notes (id, text) values (11,"Ticket <ticket_id> has been reopened by <reporter> from <server>.\nBelow is the comment.\n-----\n<ticket_comment>\n-----");

delete from Notifications;
replace into Notifications (id, note_id, subj, send2admin, send2client) values (1, 1, 'Notification of the client creation.', 1, 1);
replace into Notifications (id, note_id, subj, send2admin, send2client) values (2, 2, 'Notification of the domain creation.', 1, 1);
replace into Notifications (id, note_id, subj, send2admin, send2client) values (3, 3, 'Notification of problem domains', 1, 1);
replace into Notifications (id, note_id, subj, send2admin, send2client) values (4, 4, 'Client account event notification: The period of validity has expired.', 1, 1);
replace into Notifications (id, note_id, subj, send2admin, send2client) values (5, 5, 'Client account event notification: The period of validity is about to expire.', 1, 1);
replace into Notifications (id, note_id, subj, send2admin, send2client) values (6, 6, 'Domain event notification: The period of validity has expired.', 1, 1);
replace into Notifications (id, note_id, subj, send2admin, send2client) values (7, 7, 'Domain event notification: The period of validity is about to expire.', 1, 1);
replace into Notifications (id, note_id, subj, send2admin, send2client) values (8, 8, 'Help Desk event notification: Ticket has been created.', 1, 1);
replace into Notifications (id, note_id, subj, send2admin, send2client) values (9, 9, 'Help Desk event notification: Ticket has been commented.', 1, 1);
replace into Notifications (id, note_id, subj, send2admin, send2client) values (10,10,'Help Desk event notification: Ticket has been closed.', 1, 1);
replace into Notifications (id, note_id, subj, send2admin, send2client) values (11,11,'Help Desk event notification: Ticket has been reopened.', 1, 1);

delete from Skins;
replace into Skins (id, name, place) values (1, 'WinXP Blue','winxp.blue');
replace into Skins (id, name, place) values (2, 'WinXP Olivegreen','winxp.olivegreen');
replace into Skins (id, name, place) values (3, 'WinXP Silver','winxp.silver');
replace into Skins (id, name, place) values (4, 'Plesk Silver','plesk.silver');
replace into Skins (id, name, place) values (5, 'Plesk Classic Silver','plesk.classic.silver');
replace into Skins (id, name, place) values (6, 'WinXP Reloaded','winxp.new');
replace into Skins (id, name, place) values (7, 'Aqua','aqua');
replace into Skins (id, name, place) values (8, 'WinXP Reloaded Compact','winxp.new.compact');
replace into Skins (id, name, place) values (9, 'Aqua Compact','aqua.compact');
replace into Skins (id, name, place) values (10, 'Longhorn Aero','longhorn.aero');
replace into Skins (id, name, place) values (11, 'Longhorn Black','longhorn.black');
replace into Skins (id, name, place) values (12, 'Longhorn Yellow','longhorn.yellow');
replace into Skins (id, name, place) values (13, 'Plesk Sea','plesk.sea');
replace into Skins (id, name, place) values (14, 'Plesk Violet','plesk.violet');
replace into Skins (id, name, place) values (15, 'Plesk Nature','plesk.nature');
replace into Skins (id, name, place) values (16, 'Plesk Blue','plesk.blue');

delete from actions;
replace into actions(name, descr, enabled) values ('admin_update', 'Update Administrator Information', 'true');
replace into actions(name, descr, enabled) values ('service_stop', 'Stop Service', 'true');
replace into actions(name, descr, enabled) values ('service_start', 'Start Service', 'true');
replace into actions(name, descr, enabled) values ('service_restart', 'Restart Service', 'true');
replace into actions(name, descr, enabled) values ('ip_address_create', 'Create IP Address', 'true');
replace into actions(name, descr, enabled) values ('ip_address_update', 'Update IP Address', 'true');
replace into actions(name, descr, enabled) values ('ip_address_delete', 'Delete IP Address', 'true');
replace into actions(name, descr, enabled) values ('client_create', 'Create Client', 'true');
replace into actions(name, descr, enabled) values ('client_update', 'Update Client', 'true');
replace into actions(name, descr, enabled) values ('client_delete', 'Delete Client', 'true');
replace into actions(name, descr, enabled) values ('client_status_update', 'Update Client Status', 'true');
replace into actions(name, descr, enabled) values ('client_preferences_update', 'Update Client Preferences', 'true');
replace into actions(name, descr, enabled) values ('client_ip_pool_update', 'Update Client IP Pool', 'true');
replace into actions(name, descr, enabled) values ('client_siteapp_added', 'Site Application Package added to Client Pool', 'true');
replace into actions(name, descr, enabled) values ('client_siteapp_removed', 'Site Application Package removed from Client Pool', 'true');
replace into actions(name, descr, enabled) values ('client_limit_size_reached', 'Client\'s disk space limit reached', 'true');
replace into actions(name, descr, enabled) values ('client_limit_traffic_reached', 'Client\'s traffic limit reached', 'true');
replace into actions(name, descr, enabled) values ('domain_create', 'Create Domain', 'true');
replace into actions(name, descr, enabled) values ('domain_update', 'Update Domain', 'true');
replace into actions(name, descr, enabled) values ('domain_delete', 'Delete Domain', 'true');
replace into actions(name, descr, enabled) values ('domain_owner_change', 'Change Domain Owner', 'true');
replace into actions(name, descr, enabled) values ('domain_status_update', 'Update Domain Status', 'true');
replace into actions(name, descr, enabled) values ('domain_dns_update', 'Update Domain DNS Zone', 'true');
replace into actions(name, descr, enabled) values ('domain_limit_size_reached', 'Domain\'s disk space limit reached', 'true');
replace into actions(name, descr, enabled) values ('domain_limit_traffic_reached', 'Domain\'s traffic limit reached', 'true');
replace into actions(name, descr, enabled) values ('subdomain_create', 'Create Subdomain', 'true');
replace into actions(name, descr, enabled) values ('subdomain_update', 'Update Subdomain', 'true');
replace into actions(name, descr, enabled) values ('subdomain_delete', 'Delete Subdomain', 'true');
replace into actions(name, descr, enabled) values ('phys_hosting_create', 'Create Physical Hosting', 'true');
replace into actions(name, descr, enabled) values ('phys_hosting_update', 'Update Physical Hosting', 'true');
replace into actions(name, descr, enabled) values ('phys_hosting_delete', 'Delete Physical Hosting', 'true');
replace into actions(name, descr, enabled) values ('forwarding_create', 'Create Standard/Frame forwarding', 'true');
replace into actions(name, descr, enabled) values ('forwarding_update', 'Update Standard/Frame forwarding', 'true');
replace into actions(name, descr, enabled) values ('forwarding_delete', 'Delete Standard/Frame forwarding', 'true');
replace into actions(name, descr, enabled) values ('mailname_create', 'Create Mailname', 'true');
replace into actions(name, descr, enabled) values ('mailname_update', 'Update Mailname', 'true');
replace into actions(name, descr, enabled) values ('mailname_delete', 'Delete Mailname', 'true');
replace into actions(name, descr, enabled) values ('webuser_create', 'Create WebUser', 'true');
replace into actions(name, descr, enabled) values ('webuser_update', 'Update WebUser', 'true');
replace into actions(name, descr, enabled) values ('webuser_delete', 'Delete WebUser', 'true');
replace into actions(name, descr, enabled) values ('client_limits_update', 'Update Client Limits', 'true');
replace into actions(name, descr, enabled) values ('domain_limits_update', 'Update Domain Limits', 'true');
replace into actions(name, descr, enabled) values ('client_permissions_update', 'Update Client Permissions', 'true');
replace into actions(name, descr, enabled) values ('maillist_create', 'Create Mail list', 'true');
replace into actions(name, descr, enabled) values ('maillist_update', 'Update Mail list', 'true');
replace into actions(name, descr, enabled) values ('maillist_delete', 'Delete Mail list', 'true');
replace into actions(name, descr, enabled) values ('cp_user_login', 'CP User Login', 'true');
replace into actions(name, descr, enabled) values ('cp_user_logout', 'CP User Logout', 'true');
replace into actions(name, descr, enabled) values ('dl_user_update', 'Domain User Update', 'true');

replace into actions(name, descr, enabled) values ('siteapp_install', 'Install Site Application', 'true');
replace into actions(name, descr, enabled) values ('siteapp_reconfigure', 'Reconfigure Site Application', 'true');
replace into actions(name, descr, enabled) values ('siteapp_unchain', 'Unchain site application', 'true');
replace into actions(name, descr, enabled) values ('siteapp_uninstall', 'Uninstall site application', 'true');

replace into actions(name, descr, enabled) values ('license_update', 'License updated', 'true');
replace into actions(name, descr, enabled) values ('license_expired', 'License expired', 'true');

delete from tts_queues;
replace into tts_queues (id, enabled, title) values(1, 'true', '1');
replace into tts_queues (id, enabled, title) values(2, 'true', '2');
replace into tts_queues (id, enabled, title) values(3, 'true', '3');

delete from tts_priorities;
replace into tts_priorities (id, enabled, title) values(1, 'true', '1-High');
replace into tts_priorities (id, enabled, title) values(2, 'true', '2-Normal');
replace into tts_priorities (id, enabled, title) values(3, 'true', '3-Low');

delete from tts_cats;
replace into tts_cats (id, enabled, title) values(1, 'true', 'General');
replace into tts_cats (id, enabled, title) values(2, 'true', 'Hosting');
replace into tts_cats (id, enabled, title) values(3, 'true', 'Mail');
replace into tts_cats (id, enabled, title) values(4, 'true', 'DNS');
replace into tts_cats (id, enabled, title) values(5, 'true', 'Database');
replace into tts_cats (id, enabled, title) values(6, 'true', 'FTP');
replace into tts_cats (id, enabled, title) values(7, 'true', 'Site Applications');
replace into tts_cats (id, enabled, title) values(8, 'true', 'Tomcat');
replace into tts_cats (id, enabled, title) values(9, 'true', 'Mailing Lists');

delete from tts_conf;
replace into tts_conf (id, enabled, can_post, def_qu_id, def_pr_id, def_cat_id) values(1, 'true', 'true', 1, 2, 1);

replace into actions(name, descr, enabled) values ('siteapppkg_install', 'Install Site Application Package', 'true');
replace into actions(name, descr, enabled) values ('siteapppkg_update', 'Update of Site Application Package', 'true');
replace into actions(name, descr, enabled) values ('siteapppkg_uninstall', 'Uninstall Site Application Package', 'true');

-- enable Mailman localhost relaying
REPLACE INTO smtp_poplocks (ip_address, ip_mask) VALUES ('127.0.0.0','8');

-- PSA database version upgrade
-- replace into misc (param,val) values('version', '0650');	-- just for info, filled by installer
